@@ -10,7 +10,7 @@ warnings.filterwarnings("ignore")
 if not hasattr(requests, 'eshost'):
 	requests.eshost	= os.getenv("eshost", "172.17.0.1") 
 	requests.esport	= int(os.getenv("esport", 9200))
-	requests.es		= Elasticsearch([ f"http://{requests.eshost}:{requests.esport}" ])  
+	requests.es		= Elasticsearch([ f"http://{requests.eshost}" ])  
 
 config = {  
 		"settings" : {
@@ -18,6 +18,7 @@ config = {
 			"number_of_shards": "3",
 			"max_result_window":"2147483647",
 			"index.mapping.ignore_malformed": "true",
+			#"index.codec" : "best_compression", # added 2022.8.21
 			"analysis": {
 			  "filter": {
 				"postag_filter": {
@@ -137,6 +138,7 @@ config = {
 			"item": { "type": "keyword"},
 			"lang": { "type": "keyword"},
 			"key": { "type": "keyword"},
+			"s": { "type": "keyword"},
 			"item_key": { "type": "keyword"},
 			"score": { "type": "float"},
 			"tmf": { "type": "float"},
@@ -145,6 +147,7 @@ config = {
 			"stroke": { "type": "keyword", "index": "false"},
 			"strokes": { "type": "keyword", "index": "false"},
 			"text": { "type": "keyword", "index": "false"},
+			"essay_or_snts": { "type": "keyword", "index": "false"},
 			"labels": { "type": "keyword"}, # for annotation 
 			"_snt": { "type": "keyword", "index": "false"},
 			"_ske": { "type": "keyword", "index": "false"},
@@ -232,6 +235,7 @@ config = {
 			"body": { "type": "text", "index": "false" },
 			"doc": { "type": "text", "index": "false" },#"doc": { "type": "keyword", "index": "false" ,"store": "false"}, # dim arr of dsk
 			"tm": { "type": "date"}, #"format": "yyyy-MM-dd HH:mm:ss || yyyy-MM-dd || yyyy/MM/dd HH:mm:ss|| yyyy/MM/dd ||epoch_millis"
+			"timestamp": { "type": "date"},
 			"sdate": { "type": "date",  "format": "yyyy-MM-dd"},
 			"csv": { "type": "keyword",  "index": "false"},
 			"tsv": { "type": "keyword",  "index": "false"},
@@ -247,25 +251,25 @@ config = {
 	}
 
 newindex= lambda idxname : (requests.es.indices.delete(idxname) if requests.es.indices.exists(idxname) else None, requests.es.indices.create(idxname, config))[1] # body=
-rows	= lambda query: requests.post(f"http://{requests.eshost}:{requests.esport}/_sql",json={"query": query}).json().get('rows',[]) 
-sql		= lambda query: requests.post(f"http://{requests.eshost}:{requests.esport}/_sql",json={"query": query}).json().get('rows',[]) 
+rows	= lambda query: requests.post(f"http://{requests.eshost}/_sql",json={"query": query}).json().get('rows',[]) 
+sql		= lambda query: requests.post(f"http://{requests.eshost}/_sql",json={"query": query}).json().get('rows',[]) 
 sntnum	= lambda cp: sql(f"select count(*) cnt from {cp} where type = 'snt'" )[0][0] #75222
 sntsum	= lambda cp: sql(f"select count(*) cnt from {cp} where type = 'snt'" )[0][0] # added 2022.6.29
 lexsum	= lambda cp: sql(f"select count(*) cnt from {cp} where type = 'tok'" )[0][0] 
 lexnum	= lambda w,cp: sql(f"select count(*) cnt from {cp} where low = '{w}' and type = 'tok'")[0][0] # opened = 70
 lemnum	= lambda w,cp: sql(f"select count(*) cnt from {cp} where lem = '{w}' and type = 'tok'")[0][0] 
 sqlsi	= lambda query: (si:=Counter(), [si.update({row[0]:1}) for row in sql(query)])[0]
-warmup  = lambda : requests.put(f"http://{requests.eshost}:{requests.esport}/_cluster/settings", json={"persistent": {"search.max_buckets": 1000000}}).text
+warmup  = lambda : requests.put(f"http://{requests.eshost}/_cluster/settings", json={"persistent": {"search.max_buckets": 1000000}}).text
 kwic	= lambda cp, w, topk=3 : [ re.sub(rf"\b({w})\b", f"<b>{w}</b>", row[0]) for row in rows(f"select snt from {cp} where type = 'snt' and match (snt, '{w}') limit {topk}")]
 
 def sqlrow(query="select lem, count(*) cnt  from gzjc where type = 'tok' and pos != 'PUNCT' group by lem order by cnt desc limit 10"):
 	''' {'columns': [{'name': 'lem', 'type': 'keyword'}, {'name': 'cnt', 'type': 'long'}], 'rows': [['the', 7552], ['be', 5640], ['and', 3604], ['to', 3561], ['of', 3127], ['a', 2902], ['in', 2687], ['I', 2063], ['have', 1562], ['it', 1311]]} '''
-	res = requests.post(f"http://{requests.eshost}:{requests.esport}/_sql",json={"query": query}).json() 
+	res = requests.post(f"http://{requests.eshost}/_sql",json={"query": query}).json() 
 	columns = [ ar['name'] for ar in res['columns'] ]
 	return  [  dict(zip(columns, ar)) for ar in res['rows'] ] #[{'lem': 'the', 'cnt': 7552}, {'lem': 'be', 'cnt': 5640}, {'lem': 'and', 'cnt': 3604}, {'lem': 'to', 'cnt': 3561}, {'lem': 'of', 'cnt': 3127}, {'lem': 'a', 'cnt': 2902}, {'lem': 'in', 'cnt': 2687}, {'lem': 'I', 'cnt': 2063}, {'lem': 'have', 'cnt': 1562}, {'lem': 'it', 'cnt': 1311}]
 
 ## added 2022.7.3
-requests.esname = os.getenv("esname", "es.corpusly.com:9200")
+requests.eshost	= os.getenv('eshost', 'es.corpusly.com:9200') #requests.esname = os.getenv("esname", "es.corpusly.com:9200")
 cursor_sql = lambda query, cursor: requests.post(f"http://{requests.esname}/_sql", json={"query":query, "cursor":cursor}).json() 
 
 def cursor_rows(query="select dep, gov, lem, pos, count(*) cnt from gzjc where type='tok' group by dep, gov, lem, pos"):
@@ -278,6 +282,14 @@ def cursor_rows(query="select dep, gov, lem, pos, count(*) cnt from gzjc where t
 		if not cursor: break
 	return rows 
 
+def walk(query): 
+	cursor=''
+	while True : 
+		res = cursor_sql(query, cursor)  
+		yield res['rows']
+		cursor = res.get('cursor','') 
+		if not cursor: break
+
 def sqlsi(query): #select lex, count(*)
 	si = Counter()
 	cursor=''
@@ -372,7 +384,7 @@ def ids(_ids:list, cp:str='inau'):
 			}
 		}
 	}
-	return requests.post(f"http://{requests.eshost}:{requests.esport}/{cp}/_search/", json=sql).json()
+	return requests.post(f"http://{requests.eshost}/{cp}/_search/", json=sql).json()
 
 def term_to_snts(sql): 
 	rows = requests.es.sql(sql) #f"select src from {cp} where type = 'trp' and gov='{gov}' and rel='{rel}' and dep='{dep}' limit {topk}"
@@ -384,7 +396,7 @@ def term_to_snts(sql):
 			}
 		}
 	}
-	return requests.post(f"http://{requests.eshost}:{requests.esport}/{cp}/_search/", json=sql).json()
+	return requests.post(f"http://{requests.eshost}/{cp}/_search/", json=sql).json()
 
 def match_phrase(phrase:str='opened the box', cp:str='clec', topk:int=10): 
 	''' '''
@@ -396,7 +408,7 @@ def match_phrase(phrase:str='opened the box', cp:str='clec', topk:int=10):
   }
   , "size": topk
 }
-	return requests.post(f"http://{requests.eshost}:{requests.esport}/{cp}/_search/", json=sql).json()
+	return requests.post(f"http://{requests.eshost}/{cp}/_search/", json=sql).json()
 
 phrase_num = lambda phrase, cp='clec', topk=10: match_phrase(phrase, cp, topk)["hits"]["total"]["value"]
 
@@ -416,7 +428,7 @@ def hybchunk(hyb:str='the _NNS of', index:str='gzjc', size:int= -1, topk:int=10)
   },
   "size":  size
 }
-	res = requests.post(f"http://{requests.eshost}:{requests.esport}/{index}/_search/", json=sql).json()
+	res = requests.post(f"http://{requests.eshost}/{index}/_search/", json=sql).json()
 	si = Counter()
 	repat = rehyb(hyb)
 	for ar in res['hits']['hits']: 
