@@ -4,12 +4,12 @@ from collections import Counter , defaultdict
 from elasticsearch import Elasticsearch,helpers
 import so 
 
-def esjson_load(infile, idxname:str=None, batch=1000000, refresh:bool=True, eshost='127.0.0.1',esport=9200): 
+def esjson_load(infile, idxname:str=None, batch=100000, refresh:bool=True, eshost='127.0.0.1',esport=9200): 
 	''' python3 -m so.loades gzjc.esjson.gz '''
 	es	  = Elasticsearch([ f"http://{eshost}:{esport}" ])  
 	if not idxname : idxname = infile.split('.')[0]
 	print(">>started: " , infile, idxname, flush=True )
-	if refresh: 
+	if refresh or not es.indices.exists(index=idxname): 
 		if es.indices.exists(index=idxname):es.indices.delete(index=idxname)
 		es.indices.create(index=idxname, body=so.config) #, body=snt_mapping
 
